/****************************************************************************
** Meta object code from reading C++ file 'filecontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../deepin-image-viewer/src/src/filecontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filecontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11FileControlE_t {};
} // unnamed namespace

template <> constexpr inline auto FileControl::qt_create_metaobjectdata<qt_meta_tag_ZN11FileControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileControl",
        "openImageFile",
        "",
        "fileName",
        "imageRenamed",
        "QUrl",
        "oldName",
        "newName",
        "imageFileChanged",
        "standardPicturesPath",
        "resetImageFiles",
        "filePaths",
        "getDirImagePath",
        "path",
        "isCurrentWatcherDir",
        "slotGetInfo",
        "key",
        "slotGetFileName",
        "slotGetFileNameSuffix",
        "getNamePath",
        "oldPath",
        "slotFileSuffix",
        "ret",
        "setWallpaper",
        "imgPath",
        "deleteImagePath",
        "displayinFileManager",
        "copyImage",
        "copyText",
        "str",
        "showPrintDialog",
        "parseCommandlineGetPath",
        "isCheckOnly",
        "isSupportSetWallpaper",
        "isCanRename",
        "isCanReadable",
        "isRotatable",
        "isCanWrite",
        "isCanDelete",
        "isImage",
        "slotFileReName",
        "name",
        "filepath",
        "isSuffix",
        "isShowToolTip",
        "getConfigValue",
        "QVariant",
        "group",
        "defaultValue",
        "setConfigValue",
        "value",
        "saveSetting",
        "getlastWidth",
        "getlastHeight",
        "setSettingWidth",
        "width",
        "setSettingHeight",
        "height",
        "setEnableNavigation",
        "b",
        "isEnableNavigation",
        "getCompanyLogo",
        "showShortcutPanel",
        "windowCenterX",
        "windowCenterY",
        "terminateShortcutPanelProcess"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openImageFile'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'imageRenamed'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'imageFileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Method 'standardPicturesPath'
        QtMocHelpers::MethodData<QString() const>(9, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'resetImageFiles'
        QtMocHelpers::MethodData<void(const QStringList &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Method 'resetImageFiles'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'getDirImagePath'
        QtMocHelpers::MethodData<QStringList(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isCurrentWatcherDir'
        QtMocHelpers::MethodData<bool(const QUrl &)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Method 'slotGetInfo'
        QtMocHelpers::MethodData<QString(const QString &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 13 },
        }}),
        // Method 'slotGetFileName'
        QtMocHelpers::MethodData<QString(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'slotGetFileNameSuffix'
        QtMocHelpers::MethodData<QString(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'getNamePath'
        QtMocHelpers::MethodData<QString(const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 7 },
        }}),
        // Method 'slotFileSuffix'
        QtMocHelpers::MethodData<QString(const QString &, bool)>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 13 }, { QMetaType::Bool, 22 },
        }}),
        // Method 'slotFileSuffix'
        QtMocHelpers::MethodData<QString(const QString &)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'setWallpaper'
        QtMocHelpers::MethodData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Method 'deleteImagePath'
        QtMocHelpers::MethodData<bool(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'displayinFileManager'
        QtMocHelpers::MethodData<bool(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'copyImage'
        QtMocHelpers::MethodData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'copyText'
        QtMocHelpers::MethodData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'showPrintDialog'
        QtMocHelpers::MethodData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'parseCommandlineGetPath'
        QtMocHelpers::MethodData<QString()>(31, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'isCheckOnly'
        QtMocHelpers::MethodData<bool()>(32, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isSupportSetWallpaper'
        QtMocHelpers::MethodData<bool(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isCanRename'
        QtMocHelpers::MethodData<bool(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isCanReadable'
        QtMocHelpers::MethodData<bool(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isRotatable'
        QtMocHelpers::MethodData<bool(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isCanWrite'
        QtMocHelpers::MethodData<bool(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isCanDelete'
        QtMocHelpers::MethodData<bool(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'isImage'
        QtMocHelpers::MethodData<bool(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'slotFileReName'
        QtMocHelpers::MethodData<bool(const QString &, const QString &, bool)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Method 'slotFileReName'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 42 },
        }}),
        // Method 'isShowToolTip'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 41 },
        }}),
        // Method 'getConfigValue'
        QtMocHelpers::MethodData<QVariant(const QString &, const QString &, const QVariant &)>(45, 2, QMC::AccessPublic, 0x80000000 | 46, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 16 }, { 0x80000000 | 46, 48 },
        }}),
        // Method 'getConfigValue'
        QtMocHelpers::MethodData<QVariant(const QString &, const QString &)>(45, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 46, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 16 },
        }}),
        // Method 'setConfigValue'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QVariant &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 47 }, { QMetaType::QString, 16 }, { 0x80000000 | 46, 50 },
        }}),
        // Method 'saveSetting'
        QtMocHelpers::MethodData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'getlastWidth'
        QtMocHelpers::MethodData<int()>(52, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'getlastHeight'
        QtMocHelpers::MethodData<int()>(53, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'setSettingWidth'
        QtMocHelpers::MethodData<void(int)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Method 'setSettingHeight'
        QtMocHelpers::MethodData<void(int)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 57 },
        }}),
        // Method 'setEnableNavigation'
        QtMocHelpers::MethodData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Method 'isEnableNavigation'
        QtMocHelpers::MethodData<bool()>(60, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'getCompanyLogo'
        QtMocHelpers::MethodData<QUrl()>(61, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Method 'showShortcutPanel'
        QtMocHelpers::MethodData<void(int, int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 63 }, { QMetaType::Int, 64 },
        }}),
        // Method 'terminateShortcutPanelProcess'
        QtMocHelpers::MethodData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileControl, qt_meta_tag_ZN11FileControlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FileControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FileControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FileControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11FileControlE_t>.metaTypes,
    nullptr
} };

void FileControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openImageFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->imageRenamed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 2: _t->imageFileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: { QString _r = _t->standardPicturesPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->resetImageFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->resetImageFiles(); break;
        case 6: { QStringList _r = _t->getDirImagePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isCurrentWatcherDir((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->slotGetInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->slotGetFileName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->slotGetFileNameSuffix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->getNamePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->slotFileSuffix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->slotFileSuffix((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { bool _r = _t->deleteImagePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->displayinFileManager((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->copyImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->copyText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->showPrintDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: { QString _r = _t->parseCommandlineGetPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->isCheckOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->isSupportSetWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->isCanRename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->isCanReadable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->isRotatable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->isCanWrite((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->isCanDelete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->isImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->slotFileReName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->slotFileReName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->isShowToolTip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { QVariant _r = _t->getConfigValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 33: { QVariant _r = _t->getConfigValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->setConfigValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 35: _t->saveSetting(); break;
        case 36: { int _r = _t->getlastWidth();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 37: { int _r = _t->getlastHeight();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->setSettingWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->setSettingHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->setEnableNavigation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: { bool _r = _t->isEnableNavigation();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { QUrl _r = _t->getCompanyLogo();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->showShortcutPanel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 44: _t->terminateShortcutPanelProcess(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileControl::*)(const QString & )>(_a, &FileControl::openImageFile, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileControl::*)(const QUrl & , const QUrl & )>(_a, &FileControl::imageRenamed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileControl::*)(const QString & )>(_a, &FileControl::imageFileChanged, 2))
            return;
    }
}

const QMetaObject *FileControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FileControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FileControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void FileControl::openImageFile(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FileControl::imageRenamed(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void FileControl::imageFileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
