// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "types.h"

Types::Types(QObject *parent)
    : QObject(parent)
{
}

Types::~Types() {}
