/****************************************************************************
** Meta object code from reading C++ file 'globalstatus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../deepin-image-viewer/src/src/globalstatus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'globalstatus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12GlobalStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto GlobalStatus::qt_create_metaobjectdata<qt_meta_tag_ZN12GlobalStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GlobalStatus",
        "showFullScreenChanged",
        "",
        "enableNavigationChanged",
        "showRightMenuChanged",
        "showImageInfoChanged",
        "viewInteractiveChanged",
        "viewFlickingChanged",
        "animationBlockChanged",
        "fullScreenAnimatingChanged",
        "thumbnailVaildWidthChanged",
        "stackPageChanged",
        "minHeight",
        "minWidth",
        "minHideHeight",
        "floatMargin",
        "titleHeight",
        "thumbnailViewHeight",
        "showBottomY",
        "switchImageHotspotWidth",
        "actionMargin",
        "rightMenuItemHeight",
        "animationDefaultDuration",
        "pathViewItemCount",
        "showFullScreen",
        "enableNavigation",
        "showRightMenu",
        "showImageInfo",
        "viewInteractive",
        "viewFlicking",
        "animationBlock",
        "fullScreenAnimating",
        "thumbnailVaildWidth",
        "stackPage",
        "Types::StackPage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showFullScreenChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableNavigationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRightMenuChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showImageInfoChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewInteractiveChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewFlickingChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animationBlockChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullScreenAnimatingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thumbnailVaildWidthChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stackPageChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'minHeight'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minWidth'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minHideHeight'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'floatMargin'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titleHeight'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'thumbnailViewHeight'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showBottomY'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'switchImageHotspotWidth'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'actionMargin'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rightMenuItemHeight'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'animationDefaultDuration'
        QtMocHelpers::PropertyData<double>(22, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pathViewItemCount'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showFullScreen'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'enableNavigation'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'showRightMenu'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'showImageInfo'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'viewInteractive'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'viewFlicking'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'animationBlock'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'fullScreenAnimating'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'thumbnailVaildWidth'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'stackPage'
        QtMocHelpers::PropertyData<Types::StackPage>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GlobalStatus, qt_meta_tag_ZN12GlobalStatusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12GlobalStatusE[] = {
    QMetaObject::SuperData::link<Types::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject GlobalStatus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GlobalStatusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GlobalStatusE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12GlobalStatusE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12GlobalStatusE_t>.metaTypes,
    nullptr
} };

void GlobalStatus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalStatus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showFullScreenChanged(); break;
        case 1: _t->enableNavigationChanged(); break;
        case 2: _t->showRightMenuChanged(); break;
        case 3: _t->showImageInfoChanged(); break;
        case 4: _t->viewInteractiveChanged(); break;
        case 5: _t->viewFlickingChanged(); break;
        case 6: _t->animationBlockChanged(); break;
        case 7: _t->fullScreenAnimatingChanged(); break;
        case 8: _t->thumbnailVaildWidthChanged(); break;
        case 9: _t->stackPageChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::showFullScreenChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::enableNavigationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::showRightMenuChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::showImageInfoChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::viewInteractiveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::viewFlickingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::animationBlockChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::fullScreenAnimatingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::thumbnailVaildWidthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalStatus::*)()>(_a, &GlobalStatus::stackPageChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->minHeight(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->minWidth(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->minHideHeight(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->floatMargin(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->titleHeight(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->thumbnailViewHeight(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->showBottomY(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->switchImageHotspotWidth(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->actionMargin(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->rightMenuItemHeight(); break;
        case 10: *reinterpret_cast<double*>(_v) = _t->animationDefaultDuration(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->pathViewItemCount(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->showFullScreen(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->enableNavigation(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->showRightMenu(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->showImageInfo(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->viewInteractive(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->viewFlicking(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->animationBlock(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->fullScreenAnimating(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->thumbnailVaildWidth(); break;
        case 21: *reinterpret_cast<Types::StackPage*>(_v) = _t->stackPage(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 12: _t->setShowFullScreen(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setEnableNavigation(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setShowRightMenu(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setShowImageInfo(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setViewInteractive(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setViewFlicking(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setAnimationBlock(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setFullScreenAnimating(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setThumbnailVaildWidth(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setStackPage(*reinterpret_cast<Types::StackPage*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GlobalStatus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GlobalStatus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GlobalStatusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GlobalStatus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void GlobalStatus::showFullScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GlobalStatus::enableNavigationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GlobalStatus::showRightMenuChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GlobalStatus::showImageInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GlobalStatus::viewInteractiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GlobalStatus::viewFlickingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GlobalStatus::animationBlockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void GlobalStatus::fullScreenAnimatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GlobalStatus::thumbnailVaildWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void GlobalStatus::stackPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
