/****************************************************************************
** Meta object code from reading C++ file 'globalcontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../deepin-image-viewer/src/src/globalcontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'globalcontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13GlobalControlE_t {};
} // unnamed namespace

template <> constexpr inline auto GlobalControl::qt_create_metaobjectdata<qt_meta_tag_ZN13GlobalControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GlobalControl",
        "currentSourceChanged",
        "",
        "currentIndexChanged",
        "currentFrameIndexChanged",
        "imageCountChanged",
        "changeRotationCacheBegin",
        "currentRotationChanged",
        "requestRotateCacheImage",
        "hasPreviousImageChanged",
        "hasNextImageChanged",
        "requestRotateImage",
        "localPath",
        "rotation",
        "setImageFiles",
        "imageFiles",
        "openFile",
        "removeImage",
        "QUrl",
        "renameImage",
        "oldName",
        "newName",
        "submitImageChangeImmediately",
        "setIndexAndFrameIndex",
        "index",
        "frameIndex",
        "previousImage",
        "nextImage",
        "firstImage",
        "lastImage",
        "forceExit",
        "globalModel",
        "ImageSourceModel*",
        "viewModel",
        "PathViewProxyModel*",
        "currentSource",
        "currentIndex",
        "currentFrameIndex",
        "imageCount",
        "currentRotation",
        "hasPreviousImage",
        "hasNextImage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentSourceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentFrameIndexChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageCountChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changeRotationCacheBegin'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentRotationChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestRotateCacheImage'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasPreviousImageChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasNextImageChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestRotateImage'
        QtMocHelpers::SignalData<void(const QString &, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'setImageFiles'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'removeImage'
        QtMocHelpers::SlotData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 17 },
        }}),
        // Slot 'renameImage'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 20 }, { 0x80000000 | 18, 21 },
        }}),
        // Slot 'submitImageChangeImmediately'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setIndexAndFrameIndex'
        QtMocHelpers::MethodData<void(int, int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Method 'previousImage'
        QtMocHelpers::MethodData<bool()>(26, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'nextImage'
        QtMocHelpers::MethodData<bool()>(27, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'firstImage'
        QtMocHelpers::MethodData<bool()>(28, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'lastImage'
        QtMocHelpers::MethodData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'forceExit'
        QtMocHelpers::MethodData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'globalModel'
        QtMocHelpers::PropertyData<ImageSourceModel*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewModel'
        QtMocHelpers::PropertyData<PathViewProxyModel*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentSource'
        QtMocHelpers::PropertyData<QUrl>(35, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'currentFrameIndex'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'imageCount'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'currentRotation'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'hasPreviousImage'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'hasNextImage'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GlobalControl, qt_meta_tag_ZN13GlobalControlE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GlobalControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13GlobalControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13GlobalControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13GlobalControlE_t>.metaTypes,
    nullptr
} };

void GlobalControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentSourceChanged(); break;
        case 1: _t->currentIndexChanged(); break;
        case 2: _t->currentFrameIndexChanged(); break;
        case 3: _t->imageCountChanged(); break;
        case 4: _t->changeRotationCacheBegin(); break;
        case 5: _t->currentRotationChanged(); break;
        case 6: _t->requestRotateCacheImage(); break;
        case 7: _t->hasPreviousImageChanged(); break;
        case 8: _t->hasNextImageChanged(); break;
        case 9: _t->requestRotateImage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->setImageFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->removeImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->renameImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 13: _t->submitImageChangeImmediately(); break;
        case 14: _t->setIndexAndFrameIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: { bool _r = _t->previousImage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->nextImage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->firstImage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->lastImage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->forceExit(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::currentSourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::currentIndexChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::currentFrameIndexChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::imageCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::changeRotationCacheBegin, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::currentRotationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::requestRotateCacheImage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::hasPreviousImageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)()>(_a, &GlobalControl::hasNextImageChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalControl::*)(const QString & , int )>(_a, &GlobalControl::requestRotateImage, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ImageSourceModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PathViewProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ImageSourceModel**>(_v) = _t->globalModel(); break;
        case 1: *reinterpret_cast<PathViewProxyModel**>(_v) = _t->viewModel(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->currentSource(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->currentFrameIndex(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->imageCount(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->currentRotation(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hasPreviousImage(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasNextImage(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCurrentSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 3: _t->setCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setCurrentFrameIndex(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setCurrentRotation(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GlobalControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GlobalControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13GlobalControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GlobalControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void GlobalControl::currentSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GlobalControl::currentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GlobalControl::currentFrameIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GlobalControl::imageCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void GlobalControl::changeRotationCacheBegin()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void GlobalControl::currentRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void GlobalControl::requestRotateCacheImage()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void GlobalControl::hasPreviousImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GlobalControl::hasNextImageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void GlobalControl::requestRotateImage(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}
QT_WARNING_POP
